import {
  MenderTooltipClickable
} from "./chunk-YYRZB2UY.js";

// src/docslink.js
import React, { forwardRef, useState } from "react";
import { useSelector } from "react-redux";
import { Description as DescriptionIcon } from "@mui/icons-material";
import { Chip, Collapse, chipClasses } from "@mui/material";
import { makeStyles } from "tss-react/mui";
import { TIMEOUTS } from "@northern.tech/store/constants";
import { getDocsVersion, getFeatures } from "@northern.tech/store/selectors";
import { useDebounce } from "@northern.tech/utils/debouncehook";
import { jsx, jsxs } from "react/jsx-runtime";
var useStyles = makeStyles()((theme) => ({
  iconAura: {
    position: "absolute",
    top: -6,
    bottom: -4,
    left: -7,
    right: -6.5,
    border: `1px dashed ${theme.palette.text.disabled}`,
    borderRadius: "50%",
    "&.hovering": {
      borderColor: "transparent"
    }
  },
  chip: {
    borderStyle: "dashed",
    [`.${chipClasses.deleteIcon}`]: {
      fontSize: "smaller"
    },
    "&.not-hovering": {
      borderColor: "transparent",
      color: theme.palette.text.disabled,
      [`.${chipClasses.deleteIcon}`]: {
        color: theme.palette.text.disabled
      },
      [`.${chipClasses.label}`]: {
        paddingLeft: 0,
        visibility: "collapse"
      }
    }
  }
}));
var DOCSTIPS = {
  deviceConfig: { id: "deviceConfig", path: "add-ons/configure" },
  dynamicGroups: { id: "dynamicGroups", path: "overview/device-group#dynamic-group" },
  limitedDeployments: { id: "limitedDeployments", path: "overview/deployment#deployment-to-dynamic-groups" },
  phasedDeployments: { id: "phasedDeployments", path: "overview/customize-the-update-process" },
  pausedDeployments: { id: "pausedDeployments", path: "overview/customize-the-update-process#synchronized-updates" },
  retryDeployments: { id: "retryDeployments", path: "overview/deployment" },
  releases: { id: "releases", path: "overview/artifact" },
  webhookSecret: { id: "webhookSecret", path: "server-integration/webhooks#signature-header" }
};
var DocsTooltip = ({ anchor = {}, id = "", ...props }) => {
  const [isHovering, setIsHovering] = useState(false);
  const debouncedHovering = useDebounce(isHovering, TIMEOUTS.debounceDefault);
  const docsVersion = useSelector(getDocsVersion);
  const { isHosted } = useSelector(getFeatures);
  const { classes } = useStyles();
  const { content, path } = DOCSTIPS[id] || {};
  const target = `https://docs.mender.io/${docsVersion}${path}`;
  const onClick = () => {
    const docsParams = { headers: { "x-mender-docs": docsVersion } };
    fetch(target, isHosted ? {} : docsParams);
    window.open(target, "_blank");
  };
  const hoverClass = debouncedHovering ? "hovering" : "not-hovering";
  return /* @__PURE__ */ jsx(
    MenderTooltipClickable,
    {
      placement: "bottom-start",
      disableFocusListener: false,
      disableHoverListener: false,
      disableTouchListener: false,
      style: anchor,
      title: content,
      ...props,
      children: /* @__PURE__ */ jsx(
        Chip,
        {
          color: "primary",
          className: `${classes.chip} ${hoverClass}`,
          label: /* @__PURE__ */ jsx(Collapse, { in: debouncedHovering, orientation: "horizontal", children: "Learn more" }),
          deleteIcon: /* @__PURE__ */ jsxs("div", { className: "relative", children: [
            /* @__PURE__ */ jsx(DescriptionIcon, { fontSize: "small" }),
            /* @__PURE__ */ jsx("div", { className: `${classes.iconAura} ${hoverClass}` })
          ] }),
          onClick,
          onDelete: onClick,
          onMouseOver: () => setIsHovering(true),
          onMouseOut: () => setIsHovering(false),
          variant: "outlined"
        }
      )
    }
  );
};
var DocsLink = forwardRef(({ children, className = "", path, title = "", ...remainder }, ref) => {
  const docsVersion = useSelector(getDocsVersion);
  const { isHosted } = useSelector(getFeatures);
  const target = `https://docs.mender.io/${docsVersion}${path}`;
  const onClickHandler = () => {
    const docsParams = { headers: { "x-mender-docs": docsVersion } };
    fetch(target, isHosted ? {} : docsParams);
  };
  return (
    // eslint-disable-next-line react/jsx-no-target-blank
    /* @__PURE__ */ jsx("a", { className, ...remainder, href: target, onClick: onClickHandler, ref, target: "_blank", rel: isHosted ? "noopener" : "", children: children ? children : title })
  );
});
DocsLink.displayName = "DocsLink";
var docslink_default = DocsLink;

export {
  DOCSTIPS,
  DocsTooltip,
  DocsLink,
  docslink_default
};
//# sourceMappingURL=chunk-EUHS2BAH.js.map